/**************************************************************
            ==================================
            Star Wars - The POV-Ray Collection
            ==================================

TIE_F.INC - 3D model description file for use with the
Persistence of Vision Ray-Tracer, v3.0

POV-Ray code copyright (c) 1997 D M Beattie

This model is provided for personal use only. Any use of this
model for commercial gain or profit is strictly forbidden -
please see the accompanying README.TXT and Conditions of Use
before using or distributing this model.

'Star Wars' and all associated images, designs and trademarks,
(including the designs of the vehicles and objects depicted in
the Star Wars POV-Ray Collection, except where otherwise
stated) are copyright (c) 1997 Lucasfilm Ltd.

**************************************************************/

// TIE_F.INC - TIE Fighter model definition for POV-Ray v3.0

#declare TF_Tex1=texture { //Lighter Grey Sections
  pigment {
    bozo
    colour_map {
      [0.0 colour rgb <0.65,0.65,0.67>]
      [0.5 colour rgb <0.62,0.62,0.66>]
      [1.0 colour rgb <0.63,0.64,0.67>]
    }
    scale 0.01
  }
  normal {dents 0.2 scale 0.01}
  finish {ambient 0.1 diffuse 0.8}
}

#declare TF_Tex2=texture { //Medium Gray Sections
  pigment {
    bozo
    colour_map {
      [0.0 colour rgb <0.45,0.45,0.5>]
      [0.5 colour rgb <0.47,0.47,0.52>]
      [1.0 colour rgb <0.42,0.42,0.5>]
    }
    scale 0.01
  }
  normal {dents 0.2 scale 0.01}
  finish {ambient 0.1 diffuse 0.8}
}

#declare TF_Tex3=texture { // Dark Grey Sections
  pigment {
    bozo
    colour_map {
      [0.0 colour rgb <0.3,0.3,0.35>]
      [0.5 colour rgb <0.28,0.27,0.31>]
      [1.0 colour rgb <0.29,0.31,0.35>]
    }
    scale 0.01
  }
  normal {dents 0.2 scale 0.01}
  finish {ambient 0.1 diffuse 0.8}
}

#declare TF_Screen_Tex = texture {
  pigment {colour rgb 0.01}
  finish {specular 0.5 roughness 0.01 reflection 0.3}
}

#declare TF_SolarPanel = texture { //'Striped' texture on solar panels
  pigment {
    gradient <0,0,1>
    colour_map {
      [0.0 colour rgb <0.2,0.2,0.21>]
      [0.9 colour rgb <0.2,0.2,0.21>]
      [0.9 colour rgb 0.8]
      [1 colour rgb 0.8]
    }
    scale <1,1,0.3>
    translate <0,0,20>
  }
  finish {
    specular 0.3
    roughness 0.01
  }
}

//Declare vertices of wing panels

#declare A = <0,0,3.5>
#declare B = <0,4,2.25>
#declare C = <0,4,-2.25>
#declare D = <0,0,-3.5>
#declare E = <0,-4,-2.25>
#declare F = <0,-4,2.25>
#declare O = <0,0,0>


#declare TF_PanelCentreA = object {
  union {
    object {
      intersection {
        object {cone {<0,0,0>, 0.75, <0,0.02,0>, 0.65} scale <1000,1,1> rotate <0,0,0>}
        object {cone {<0,0,0>, 0.65, <0,0.02001,0>, 0.55} scale <1000,1,1> rotate <0,70,0>}
        object {cone {<0,0,0>, 0.65, <0,0.02001,0>, 0.55} scale <1000,1,1> rotate <0,110,0>}
      }
      texture {TF_Tex3}
    }
    object {
      intersection {
        object {cone {<0,0,0>, 0.65, <0,0.025,0>, 0.55} scale <1000,1,1> rotate <0,0,0>}
        object {cone {<0,0,0>, 0.55, <0,0.0251,0>, 0.45} scale <1000,1,1> rotate <0,70,0>}
        object {cone {<0,0,0>, 0.55, <0,0.0251,0>, 0.45} scale <1000,1,1> rotate <0,110,0>}
      }
      texture {TF_Tex2}
    }
    object {
      intersection {
        object {cone {<0,0,0>, 0.45, <0,0.05001,0>, 0.35} scale <1000,1,1> rotate <0,0,0>}
        object {cone {<0,0,0>, 0.35, <0,0.05002,0>, 0.25} scale <1000,1,1> rotate <0,70,0>}
        object {cone {<0,0,0>, 0.35, <0,0.05002,0>, 0.25} scale <1000,1,1> rotate <0,110,0>}
      }
      texture {TF_Tex3}
    }
    object {
      intersection {
        object {cone {<0,0,0>, 0.25, <0,0.035,0>, 0.15} scale <1000,1,1> rotate <0,0,0>}
        object {cone {<0,0,0>, 0.5, <0,0.0351,0>, 0.4} scale <1000,1,1> rotate <0,70,0>}
        object {cone {<0,0,0>, 0.5, <0,0.0351,0>, 0.4} scale <1000,1,1> rotate <0,110,0>}
      }
      texture {TF_Tex2}
    }
  }
}

#declare TF_PanelMount = object {
  union {
    object {TF_PanelCentreA scale <2,2,2> texture {TF_Tex2}}
    object {cone {<0,0,0>, 0.14, <0,0.8,0>, 0.08} scale <8,1,0.1> texture {TF_Tex2}}
    object {cone {<0,0,0>, 0.07, <0,0.6,0>, 0.05} scale <7,1,0.1> texture {TF_Tex3} rotate <0,70,0>}
    object {cone {<0,0,0>, 0.07, <0,0.6,0>, 0.05} scale <7,1,0.1> texture {TF_Tex2} rotate <0,110,0>}
    object {cylinder {<0,0,0>, <0,0.5,0>, 0.35} texture {TF_Tex3}}
    object {cylinder {<0,0,0>, <0,0.7,0>, 0.3} texture {TF_Tex3}}
    object {cylinder {<0,0,0>, <0,2,0>, 0.25} texture {TF_Tex3}}
    object {cone {<0,1,0>, 0.3, <0,2.5,0>, 0.9} scale <0.01,1,1> texture {TF_Tex2}}
  }
  rotate <0,0,-90>
  rotate <90,0,0>
  scale <-1,1,1>
}

#declare TF_PanelCentre = object {
  TF_PanelCentreA
  rotate <0,0,-90>
  rotate <90,0,0>
  scale <1,1,1>
}

#declare TF_Panel = object {
  union {
    object {
      intersection {
        object {
          union {
            object {cone {<0,0,0>, 0.1, A, 0.05}}
            object {cone {<0,0,0>, 0.1, B, 0.05}}
            object {cone {<0,0,0>, 0.1, C, 0.05}}
            object {cone {<0,0,0>, 0.1, D, 0.05}}
            object {cone {<0,0,0>, 0.1, E, 0.05}}
            object {cone {<0,0,0>, 0.1, F, 0.05}}
          }
          scale <5,1,1>
        }
        object {
          box {<-0.05,-5,-5>, <0.05,5,5>}
        }
      }
      texture {TF_Tex1}
    }
    object {
      intersection {
        object {
          union {
            object {cone {<0,0,0>, 0.02, A, 0.02}}
            object {cone {<0,0,0>, 0.02, B, 0.02}}
            object {cone {<0,0,0>, 0.02, C, 0.02}}
            object {cone {<0,0,0>, 0.02, D, 0.02}}
            object {cone {<0,0,0>, 0.02, E, 0.02}}
            object {cone {<0,0,0>, 0.02, F, 0.02}}
          }
          scale <50,1,1>
        }
        object {
          box {<-0.075,-5,-5>, <0.075,5,5>}
        }
      }
      texture {TF_Tex2}
    }
    object {
      intersection {
        object {
          union {
            #declare R = 0.05
            object {cylinder {A, B, R}}
            object {cylinder {B, C, R}}
            object {cylinder {C, D, R}}
            object {cylinder {D, E, R}}
            object {cylinder {E, F, R}}
            object {cylinder {F, A, R}}
            object {sphere {A, R}}
            object {sphere {B, R}}
            object {sphere {C, R}}
            object {sphere {D, R}}
            object {sphere {E, R}}
            object {sphere {F, R}}
          }
          scale <5,1,1>
        }
        object {box {<-0.025,-5,-5>, <0.02,5,5>}}
      }
      texture {TF_Tex1}
    }
    object {
      intersection {
        object {
          union {
            #declare R = 0.1
            object {cylinder {A, B, R}}
            object {cylinder {B, C, R}}
            object {cylinder {C, D, R}}
            object {cylinder {D, E, R}}
            object {cylinder {E, F, R}}
            object {cylinder {F, A, R}}
            object {sphere {A, R}}
            object {sphere {B, R}}
            object {sphere {C, R}}
            object {sphere {D, R}}
            object {sphere {E, R}}
            object {sphere {F, R}}
          }
          scale <5,1,1>
        }
        object {box {<-0.05,-5,-5>, <0.01,5,5>}}
      }
      texture {TF_Tex1}
    }
    object {triangle {A,B,O} texture {TF_SolarPanel rotate <60,0,0>}}
    object {triangle {B,C,O} texture {TF_SolarPanel rotate <0,0,0>}}
    object {triangle {C,D,O} texture {TF_SolarPanel rotate <120,0,0>}}
    object {triangle {D,E,O} texture {TF_SolarPanel rotate <60,0,0>}}
    object {triangle {E,F,O} texture {TF_SolarPanel rotate <0,0,0>}}
    object {triangle {F,A,O} texture {TF_SolarPanel rotate <120,0,0>}}
    object {TF_PanelCentre}
    object {TF_PanelMount}
  }
}
#declare TF_Screen = object {
  difference {
    object {cone {<0,0,1.036>, 0.7, <0,0,1.2>, 0.3}}
    object {cone {<0,0,1.036>, 0.69, <0,0,1.19>, 0.29}}
  }
  texture {TF_Screen_Tex}
}

#declare TF_ScreenFrame = object {
  union {
    object {torus {0.7,0.015} rotate <90,0,0> translate <0,0,1.036>}
    object {torus {0.3,0.015} rotate <90,0,0> translate <0,0,1.2>}
    #declare Count = 0
    #while (Count < 360)
    object {
      cylinder {<0,0.7,1.036>, <0,0.3,1.2>, 0.015}
      rotate <0,0,Count>
    }
    #declare Count = Count + (360/8)
    #end
  }
  texture {TF_Tex2}
}

#declare Cannon = object {
  union {
    object {cylinder {<0,0,0>, <0,0,0.4>, 0.05} texture {TF_Tex3}}
    object {cylinder {<0,0,0>, <0,0,0.5>, 0.04} texture {TF_Tex3}}
    object {
      difference {
        object {cylinder {<0,0,0>, <0,0,0.65>, 0.035} texture {TF_Tex2}}
        object {cylinder {<0,0,0.5>, <0,0,0.66>, 0.03} texture {TF_Tex3}}
      }
    }
  }
}

#declare TF_Cockpit = object {
  union {
    object { //Main cockpit shape
      difference {
        object {sphere {<0,0,0>, 1.25}}
        object {sphere {<0,0,0>, 1.15}}
        object {cylinder {<0,0,0>, <0,0,2>, 0.7}}
        object {plane {<0,-1,0>, -1}} //Top cut-off for exit hatch
        object {cylinder {<0,0,-0.81>, <0,0,-1.4>, 0.55} texture {pigment {colour rgb 0.15}}}
        object {cylinder {<-0.25, -1, 0.5>, <-0.25, -1, 1>, 0.075}}
        object {cylinder {<0.25, -1, 0.5>, <0.25, -1, 1>, 0.075}}
        object { // Cutaways for laser cannon mounting
          intersection {
            object {
              union {
                object {cylinder {<-0.25, 0, 0.5>, <-0.25, 0, 1>, 0.075}}
                object {cylinder {<0.25, 0, 0.5>, <0.25, 0, 1>, 0.075}}
              }
            }
            object {plane {<0,1,0>, 0}}
          }
          scale <1,3,1>
          translate <0,-1,0>
        }
      }
      texture {
        material_map {
          tga "tcpmap.tga" once
          texture {TF_Tex2} //pigment {colour rgb <1,0,0>}}
          texture {TF_Tex3} //pigment {colour rgb 0.7}}
        }
        translate <-0.5, -0.5, 0>
        scale 2.5
      }
    }
    object {Cannon translate <-0.25,-1.025,0.5> scale <1,1,1>}
    object {Cannon translate <-0.25,-1.025,0.5> scale <-1,1,1>}
    object { // Rear end
      difference {
        object {cone {<0,0,-0.8>, 0.85, <0,0,-1.3>, 0.6}}
        object {cylinder {<0,0,-1.15>, <0,0,-1.4>, 0.5} texture {pigment {colour rgb 0.15}}}
      }
      texture {TF_Tex2}
    }
    object { //Detail on top of rear end
      union {
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-15>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-25>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-35>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-45>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,15>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,25>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,35>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,45>}
      }
      texture {pigment {colour rgb 0.25}}
    }
    object {
      difference {
        object {
          union {
            object {cylinder {<0,0,-1>, <0,0,-1.3>, 0.3}}
            #declare Count = 0
            #while (Count < 360)
            object {
              box {<-0.025,-0.6,-1.3>, <0.025, 0.6, -1>}
               rotate <0,0,Count>
            }
            #declare Count = Count + 30
            #end
          }
        }
        object {cylinder {<0,0,-1.15>, <0,0,-2>, 0.15} texture {pigment {colour rgb 0.15}}}
      }
      texture {TF_Tex2}
    }
    object {
      intersection {
        object {box {<-1.2, -0.15, -1.1>, <1.2, 0.15, 0>}}
        object {sphere {<0,0,0>, 1.4}}
      }
      texture {pigment {colour rgb 0.15}}
    }
    object {
      difference {
        object {sphere {<0,0.01,0>, 1.225}}
        object {plane {<0,1,0>, 1.025}}
      }
      texture {TF_Tex2}
    }
    object {
      difference {
        object {sphere {<0,0.01,0>, 1.25}}
        object {plane {<0,1,0>, 1.025}}
        object {box {<-0.4, 1.1, -2>, <-0.2, 1.5, 0.2>}}
        object {box {<0.4, 1.1, -2>, <0.2, 1.5, 0.2>}}
        object {box {<-0.9, 1.1, -2>, <-0.45, 1.5, 0>}}
        object {box {<0.9, 1.1, -2>, <0.45, 1.5, 0>}}
      }
      texture {
        material_map {
          tga "tcpmap.tga" once
          texture {TF_Tex2}
          texture {TF_Tex3}
        }
        translate <-0.5, -0.5, 0>
        rotate <90,0,0>
        scale 2.05
      }
    }
    object {
      cylinder {<0,1,0>, <0,1.025,0>, 0.75}
      texture {
        pigment {colour rgb 0.15}
      }
    }
    object {
      intersection {
        object {sphere {<0,0,0>, 1.35} scale <1.1, 0.75, 0.75>}
        object {cylinder {<-5,0,0>, <5,0,0>, 0.4}}
        object {sphere {<0,0,0>, 1.15} inverse}

      }
      texture {TF_Tex3}
    }
    object {TF_Screen}
    object {TF_ScreenFrame}
  }
}


#declare TieFighter = object {
  union {
    object {TF_Panel translate <3,0,0> scale <1,1,1>}
    object {TF_Panel translate <3,0,0> scale <-1,1,1>}
    object {TF_Cockpit}
  }
  scale 0.7
}
